# flake8: noqa

# import apis into api package
from kameleo.local_api_client.api.cookie_api import CookieApi
from kameleo.local_api_client.api.fingerprint_api import FingerprintApi
from kameleo.local_api_client.api.folder_api import FolderApi
from kameleo.local_api_client.api.general_api import GeneralApi
from kameleo.local_api_client.api.kernel_api import KernelApi
from kameleo.local_api_client.api.profile_api import ProfileApi

