# coding: utf-8

# flake8: noqa

"""
    kameleo-local-api

    You can use the following API endpoints to communicate with the local running Kameleo programmatically.

    The version of the OpenAPI document: 4.3.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "4.3.0"

# import KameleoLocalApiClient into sdk package
from kameleo.local_api_client.kameleo_local_api_client import KameleoLocalApiClient

# import apis into sdk package
from kameleo.local_api_client.api.cookie_api import CookieApi
from kameleo.local_api_client.api.fingerprint_api import FingerprintApi
from kameleo.local_api_client.api.folder_api import FolderApi
from kameleo.local_api_client.api.general_api import GeneralApi
from kameleo.local_api_client.api.kernel_api import KernelApi
from kameleo.local_api_client.api.profile_api import ProfileApi

# import ApiClient
from kameleo.local_api_client.api_response import ApiResponse
from kameleo.local_api_client.api_client import ApiClient
from kameleo.local_api_client.configuration import Configuration
from kameleo.local_api_client.exceptions import OpenApiException
from kameleo.local_api_client.exceptions import ApiTypeError
from kameleo.local_api_client.exceptions import ApiValueError
from kameleo.local_api_client.exceptions import ApiKeyError
from kameleo.local_api_client.exceptions import ApiAttributeError
from kameleo.local_api_client.exceptions import ApiException

# import models into sdk package
from kameleo.local_api_client.models.add_profile_to_folder_request import AddProfileToFolderRequest
from kameleo.local_api_client.models.audio_spoofing_type import AudioSpoofingType
from kameleo.local_api_client.models.browser import Browser
from kameleo.local_api_client.models.browser_cookie import BrowserCookie
from kameleo.local_api_client.models.browser_settings import BrowserSettings
from kameleo.local_api_client.models.canvas_spoofing_type import CanvasSpoofingType
from kameleo.local_api_client.models.cookie_request import CookieRequest
from kameleo.local_api_client.models.create_folder_request import CreateFolderRequest
from kameleo.local_api_client.models.create_profile_request import CreateProfileRequest
from kameleo.local_api_client.models.delete_folder_response import DeleteFolderResponse
from kameleo.local_api_client.models.device import Device
from kameleo.local_api_client.models.device_memory_choice import DeviceMemoryChoice
from kameleo.local_api_client.models.device_memory_spoofing_type import DeviceMemorySpoofingType
from kameleo.local_api_client.models.export_profile_request import ExportProfileRequest
from kameleo.local_api_client.models.fingerprint import Fingerprint
from kameleo.local_api_client.models.fingerprint_preview import FingerprintPreview
from kameleo.local_api_client.models.folder_response import FolderResponse
from kameleo.local_api_client.models.font_spoofing_type import FontSpoofingType
from kameleo.local_api_client.models.geolocation_choice import GeolocationChoice
from kameleo.local_api_client.models.geolocation_spoofing_options import GeolocationSpoofingOptions
from kameleo.local_api_client.models.geolocation_spoofing_type import GeolocationSpoofingType
from kameleo.local_api_client.models.group_role import GroupRole
from kameleo.local_api_client.models.hardware_concurrency_choice import HardwareConcurrencyChoice
from kameleo.local_api_client.models.hardware_concurrency_spoofing_type import HardwareConcurrencySpoofingType
from kameleo.local_api_client.models.import_profile_request import ImportProfileRequest
from kameleo.local_api_client.models.kernel_response import KernelResponse
from kameleo.local_api_client.models.list_folders_response import ListFoldersResponse
from kameleo.local_api_client.models.os import Os
from kameleo.local_api_client.models.password_manager_type import PasswordManagerType
from kameleo.local_api_client.models.preference import Preference
from kameleo.local_api_client.models.problem_details import ProblemDetails
from kameleo.local_api_client.models.problem_response import ProblemResponse
from kameleo.local_api_client.models.profile_lifetime_state import ProfileLifetimeState
from kameleo.local_api_client.models.profile_minutes_quota import ProfileMinutesQuota
from kameleo.local_api_client.models.profile_preview import ProfilePreview
from kameleo.local_api_client.models.profile_response import ProfileResponse
from kameleo.local_api_client.models.profile_storage_location import ProfileStorageLocation
from kameleo.local_api_client.models.proxy_choice import ProxyChoice
from kameleo.local_api_client.models.proxy_connection_type import ProxyConnectionType
from kameleo.local_api_client.models.quota_statistics import QuotaStatistics
from kameleo.local_api_client.models.running_profiles_statistics import RunningProfilesStatistics
from kameleo.local_api_client.models.screen_choice import ScreenChoice
from kameleo.local_api_client.models.screen_spoofing_type import ScreenSpoofingType
from kameleo.local_api_client.models.server import Server
from kameleo.local_api_client.models.share_access import ShareAccess
from kameleo.local_api_client.models.share_access_request import ShareAccessRequest
from kameleo.local_api_client.models.share_group_request import ShareGroupRequest
from kameleo.local_api_client.models.sharing_options_response import SharingOptionsResponse
from kameleo.local_api_client.models.status_response import StatusResponse
from kameleo.local_api_client.models.timezone_choice import TimezoneChoice
from kameleo.local_api_client.models.timezone_spoofing_type import TimezoneSpoofingType
from kameleo.local_api_client.models.update_folder_request import UpdateFolderRequest
from kameleo.local_api_client.models.update_profile_request import UpdateProfileRequest
from kameleo.local_api_client.models.user import User
from kameleo.local_api_client.models.user_info_response import UserInfoResponse
from kameleo.local_api_client.models.validation_problem_details import ValidationProblemDetails
from kameleo.local_api_client.models.web_rtc_choice import WebRtcChoice
from kameleo.local_api_client.models.web_rtc_spoofing_options import WebRtcSpoofingOptions
from kameleo.local_api_client.models.web_rtc_spoofing_type import WebRtcSpoofingType
from kameleo.local_api_client.models.webgl_meta import WebglMeta
from kameleo.local_api_client.models.webgl_meta_choice import WebglMetaChoice
from kameleo.local_api_client.models.webgl_meta_spoofing_options import WebglMetaSpoofingOptions
from kameleo.local_api_client.models.webgl_meta_spoofing_type import WebglMetaSpoofingType
from kameleo.local_api_client.models.webgl_spoofing_type import WebglSpoofingType
