# coding: utf-8

"""
    kameleo-local-api

    You can use the following API endpoints to communicate with the local running Kameleo programmatically.

    The version of the OpenAPI document: 4.3.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DeviceMemorySpoofingType(str, Enum):
    """
    Specifies how the deviceMemory will be spoofed. Possible values:  'automatic': Automatically set the values based on the fingerprint.  'manual': Manually set the value in the profile. Valid values: 0.25, 0.5, 1, 2, 4, 8.  'off': Turn off the spoofing, use the original settings.
    """

    """
    allowed enum values
    """
    AUTOMATIC = 'automatic'
    MANUAL = 'manual'
    OFF = 'off'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DeviceMemorySpoofingType from a JSON string"""
        return cls(json.loads(json_str))


