# coding: utf-8

"""
    kameleo-local-api

    You can use the following API endpoints to communicate with the local running Kameleo programmatically.

    The version of the OpenAPI document: 4.3.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ProxyConnectionType(str, Enum):
    """
    Proxy connection settings of the profiles. Possible values:  'none': Direct connection without any proxy.  'http': Use a HTTP proxy for upstream communication.  'socks5': Use a SOCKS5 proxy for upstream communication.  'ssh': Use an SSH connection for upstream communication. Basically a SOCKS5 proxy created at the given SSH host.
    """

    """
    allowed enum values
    """
    NONE = 'none'
    HTTP = 'http'
    SOCKS5 = 'socks5'
    SSH = 'ssh'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ProxyConnectionType from a JSON string"""
        return cls(json.loads(json_str))


