# coding: utf-8

"""
    kameleo-local-api

    You can use the following API endpoints to communicate with the local running Kameleo programmatically.

    The version of the OpenAPI document: 4.3.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "kameleo.local-api-client"
VERSION = "4.3.0"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="This Python package provides convenient access to the Local API REST interface of the Kameleo Client.",
    author="Kameleo Team",
    author_email="support@kameleo.io",
    url="https://github.com/kameleo-io/local-api-client-python",
    keywords=["kameleo.local-api-client", "kameleo", "stealth browsing platform", "anti-detect browser", "selenium", "webdriver", "browser automation", "web scraping", "puppeteer", "playwright", "headless", "chrome", "firefox", "chromium", "edge"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description=open("README.md").read(),
    package_data={"kameleo.local_api_client": ["py.typed"]},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
